@@ -219,7 +219,7 @@ def alerts(context):  # pylint: disable=unused-argument
 @alerts.command(name='query',
                 help='Example: "status: closed AND teams: <opsgenie-team> AND description: *<some-hostname>*"')
 @click.option('--query', required=True)
-@click.option('--sort-by', "--sort_by", default='status')
+@click.option('--sort-by', "--sort_by")
 @click.pass_context
 def alerts_query(context, query, sort_by):
     """
@@ -235,13 +235,13 @@ def alerts_query(context, query, sort_by):
     """
     result = context.obj['opsgenie'].query_alerts(query)
     table_fields = ['message', 'tags', 'integration', 'createdAt']
-    if sort_by not in table_fields:
-        raise click.UsageError(
-            f"No column name found named: '{sort_by}'."
-        )
-    else:
-        sortedlist = sorted(result, key=itemgetter(sort_by))
-    format_table = create_and_add_to_pretty_table(table_fields, sortedlist)
+    if sort_by:
+        if sort_by not in table_fields:
+            raise click.UsageError(
+                f"No column name found named: '{sort_by}'."
+            )
+        result = sorted(result, key=itemgetter(sort_by))
+    format_table = create_and_add_to_pretty_table(table_fields, result)
 
     output = format_table if len(format_table._rows) > 0 else 'No alerts found..'
     print(output)
